<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       https://ays-pro.com/
 * @since      1.0.0
 *
 * @package    Ays_Slider
 * @subpackage Ays_Slider/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Ays_Slider
 * @subpackage Ays_Slider/admin
 * @author     Image Slider Team <info@ays-pro.com>
 */
class Ays_Slider_Admin {

    /**
     * The ID of this plugin.
     *
     * @since    1.0.0
     * @access   private
     * @var      string    $plugin_name    The ID of this plugin.
     */
    private $plugin_name;

    /**
     * The version of this plugin.
     *
     * @since    1.0.0
     * @access   private
     * @var      string    $version    The current version of this plugin.
     */
    private $version;
    private $slider_obj;
    /**
     * Initialize the class and set its properties.
     *
     * @since    1.0.0
     * @param      string    $plugin_name       The name of this plugin.
     * @param      string    $version    The version of this plugin.
     */
    public function __construct($plugin_name, $version) {

        $this->plugin_name = $plugin_name;
        $this->version = $version;
        add_filter('set-screen-option', array(__CLASS__, 'set_screen'), 10, 3);
    }

    /**
     * Register the stylesheets for the admin area.
     *
     * @since    1.0.0
     */
    public function enqueue_styles($hook_suffix) {
        wp_enqueue_style($this->plugin_name . '-admin', plugin_dir_url(__FILE__) . 'css/admin.css', array(), $this->version, 'all');
        wp_enqueue_style($this->plugin_name . '-sweetalert-css', AYS_SLD_PUBLIC_URL . '/css/ays-slider-sweetalert2.min.css', array(), $this->version, 'all');

        if (false === strpos($hook_suffix, $this->plugin_name)) {
            return;
        }

        /**
         * This function is provided for demonstration purposes only.
         *
         * An instance of this class should be passed to the run() function
         * defined in Ays_Slider_Loader as all of the hooks are defined
         * in that particular class.
         *
         * The Ays_Slider_Loader will then create the relationship
         * between the defined hooks and the functions defined in this
         * class.
         */
        wp_enqueue_style('wp-color-picker');
        
        wp_enqueue_style('ays_sld_animate.css', plugin_dir_url(__FILE__) . 'css/animate.min.css', array(), '3.7.0', 'all');
        wp_enqueue_style('ays_sld_font_awesome', plugin_dir_url(__FILE__) . 'css/font_awesome_all.css', array(), '5.6.3', 'all');
        wp_enqueue_style('ays_sld_fa_v4_shims', plugin_dir_url(__FILE__) . 'css/font_awesome_v4-shims.css', array(), '5.6.3', 'all');
        wp_enqueue_style('ays_sld_bootstrap', plugin_dir_url(__FILE__) . 'css/bootstrap.min.css', array(), '4.1.3', 'all');
        wp_enqueue_style('ays_sld_select2', plugin_dir_url(__FILE__) . 'css/select2.min.css', array(), '4.0.5', 'all');
        wp_enqueue_style($this->plugin_name, plugin_dir_url(__FILE__) . 'css/ays-slider-admin.css', array(), $this->version, 'all');
          wp_enqueue_style('ays_code_mirror', 'https://cdnjs.cloudflare.com/ajax/libs/codemirror/5.48.4/codemirror.css', array(), $this->version, 'all');
        wp_enqueue_style($this->plugin_name . '-sweetalert-css', AYS_SLD_PUBLIC_URL . '/css/ays-slider-sweetalert2.min.css', array(), $this->version, 'all');

        wp_enqueue_style($this->plugin_name . "-banner", plugin_dir_url(__FILE__) . 'css/ays-slider-banner.css', array(), time()/*$this->version*/, 'all');
    }

    /**
     * Register the JavaScript for the admin area.
     *
     * @since    1.0.0
     */
    public function enqueue_scripts($hook_suffix) {
        // wp_enqueue_script($this->plugin_name . '-adminjs', plugin_dir_url(__FILE__) . 'js/admin.js', array('jquery'), $this->version, true);
        

        if (false !== strpos($hook_suffix, "plugins.php")){
            wp_enqueue_script($this->plugin_name . '-admin', plugin_dir_url(__FILE__) . 'js/admin.js', array('jquery'), $this->version, true);
            wp_enqueue_script($this->plugin_name . '-sweetalert-js', AYS_SLD_PUBLIC_URL . '/js/ays-slider-sweetalert2.all.min.js', array('jquery'), $this->version, true );
            wp_localize_script($this->plugin_name . '-admin', 'ays_slider_ajax', array('ajax_url' => admin_url('admin-ajax.php')));
        }

        if (false === strpos($hook_suffix, $this->plugin_name)) {
            return;
        }

        /**
         * This function is provided for demonstration purposes only.
         *
         * An instance of this class should be passed to the run() function
         * defined in Ays_Slider_Loader as all of the hooks are defined
         * in that particular class.
         *
         * The Ays_Slider_Loader will then create the relationship
         * between the defined hooks and the functions defined in this
         * class.
         */
        wp_enqueue_script('jquery-effects-core');
        wp_enqueue_script('jquery-ui-sortable');
        wp_enqueue_media();
        wp_enqueue_script('wp-color-picker-alpha', plugin_dir_url(__FILE__) . 'js/wp-color-picker-alpha.min.js', array('wp-color-picker') , '2.1.3' , true);
        wp_enqueue_editor();
        wp_enqueue_script('ays_sld_popper', plugin_dir_url(__FILE__) . 'js/popper.min.js', array('jquery'), '1.14.3', true);
        wp_enqueue_script('ays_sld_bootstrap', plugin_dir_url(__FILE__) . 'js/bootstrap.min.js', array('jquery'), '4.1.3', true);
        wp_enqueue_script('ays_sld_select2', plugin_dir_url(__FILE__) . 'js/select2.min.js', array('jquery'), '4.0.5', true);
        wp_enqueue_script('ays_sld_imagesloaded', plugin_dir_url(__FILE__) . 'js/imagesloaded.pkgd.min.js', array('jquery'), '4.0.0', true);
        wp_enqueue_script($this->plugin_name, plugin_dir_url(__FILE__) . 'js/ays-slider-admin.js', array('jquery', 'wp-color-picker'), $this->version, true);
        wp_enqueue_script($this->plugin_name . '-sweetalert-js', AYS_SLD_PUBLIC_URL . '/js/ays-slider-sweetalert2.all.min.js', array('jquery'), $this->version, true );

        wp_enqueue_script( $this->plugin_name . "-banner", plugin_dir_url(__FILE__) . 'js/ays-slider-banner.js', array('jquery'), $this->version, true);
    }

     function codemirror_enqueue_scripts($hook) {
        if (false === strpos($hook, $this->plugin_name)){
            return;
        }
        if(function_exists('wp_enqueue_code_editor')){
            $cm_settings['codeEditor'] = wp_enqueue_code_editor(array(
                'type' => 'text/css',
                'codemirror' => array(
                    'inputStyle' => 'contenteditable',
                    'theme' => 'cobalt',
                   
                )
            ));

            wp_enqueue_script('wp-theme-plugin-editor');
            wp_localize_script('wp-theme-plugin-editor', 'cm_settings', $cm_settings);
        
            wp_enqueue_style('wp-codemirror');
        }
    }

    /**
     * Register the administration menu for this plugin into the WordPress Dashboard menu.
     *
     * @since    1.0.0
     */

    public function add_plugin_admin_menu() {
        add_options_page(__('Ays Slider', $this->plugin_name), __('Ays Slider', $this->plugin_name), 'manage_options', $this->plugin_name, array($this, 'display_plugin_setup_page'));
        $hook_slider = add_menu_page(__('Ays Slider', $this->plugin_name), __('Ays Slider', $this->plugin_name), 'manage_options', $this->plugin_name, array($this, 'display_plugin_setup_page'), AYS_SLD_ADMIN_URL . 'images/icon.png', '6.34');
        add_action("load-$hook_slider", [$this, 'screen_option_slider']);
    }

    /**
     * Add settings action link to the plugins page.
     *
     * @since    1.0.0
     */

    public function add_action_links($links) {
        /*
         *  Documentation : https://codex.wordpress.org/Plugin_API/Filter_Reference/plugin_action_links_(plugin_file_name)
         */
        $settings_link = array(
            '<a href="' . admin_url('options-general.php?page=' . $this->plugin_name) . '">' . __('Settings', $this->plugin_name) . '</a>',
            '<a href="https://plugins.ays-demo.com/slider-free-demo/" target="_blank">' . __('Demo', $this->plugin_name) . '</a>',
            '<a href="https://ays-pro.com/wordpress/image-slider" target="_blank" style="color:red;font-weight:bold;">' . __('Buy Now', $this->plugin_name) . '</a>',
        );
        return array_merge($settings_link, $links);

    }

    /**
     * Render the settings page for this plugin.
     *
     * @since    1.0.0
     */

    public function display_plugin_setup_page() {
        $action = (isset($_GET['action'])) ? sanitize_text_field($_GET['action']) : '';

        switch ($action) {
        case 'add':
            include_once 'partials/actions/ays-slider-admin-actions.php';
            break;
        case 'edit':
            include_once 'partials/actions/ays-slider-admin-actions.php';
            break;
        default:
            include_once 'partials/ays-slider-admin-display.php';
        }
    }

    public static function set_screen($status, $option, $value) {
        return $value;
    }

    public function screen_option_slider() {
        $option = 'per_page';
        $args = array(
            'label' => __('Sliders', $this->plugin_name),
            'default' => 20,
            'option' => 'sliders_per_page',
        );

        add_screen_option($option, $args);
        $this->slider_obj = new Ays_Slider_List_Table($this->plugin_name);
    }

    public function deactivate_plugin_option(){
        error_reporting(0);
        $request_value = $_REQUEST['upgrade_plugin'];
        $upgrade_option = get_option('ays_slider_upgrade_plugin','');
        if($upgrade_option === ''){
            add_option('ays_slider_upgrade_plugin',$request_value);
        }else{
            update_option('ays_slider_upgrade_plugin',$request_value);
        }
        echo json_encode(array('option'=>get_option('ays_slider_upgrade_plugin','')));
        wp_die();
    }

    public function register_ays_slider_widget() {
        global $wpdb;

        $sql = "SELECT COUNT(*) FROM {$wpdb->prefix}ays_slider";

        $c = $wpdb->get_var($sql);
        if (0 == $c) {return;} else {
            register_widget('Ays_Slider_Widget');
        }
    }
    public function ays_slider_admin_footer(){
        if(isset($_REQUEST['page'])){
            if(false !== strpos($_REQUEST['page'], $this->plugin_name)){
                ?>
                <p style="font-size:13px;text-align:center;font-style:italic;">
                    <span style="margin-left:0px;margin-right:10px;" class="ays_heart_beat"><i class="fa fa-heart-o animated"></i></span>
                    <span><?php echo __( "If you love our plugin, please do big favor and rate us on", $this->plugin_name); ?></span> 
                    <a target="_blank" href='https://wordpress.org/support/plugin/ays-slider/reviews/'>WordPress.org</a>
                    <span class="ays_heart_beat"><i class="fa fa-heart-o  animated"></i></span>
                </p>
            <?php
            }
        }
    }

    // public function ays_slider_sale_baner(){
        
    //     if(isset($_POST['ays_slider_sale_btn_winter'])){
    //         update_option('ays_slider_sale_notification_w', 1);
    //         update_option('ays_slider_sale_date_w', current_time( 'mysql' ));
    //     }

    //     if(isset($_POST['ays_slider_sale_btn_winter_for_two_months'])){
    //         update_option('ays_slider_sale_dismiss_for_two_month_w', 1);
    //         update_option('ays_slider_sale_date_w', current_time( 'mysql' ));
    //     }
    
    //     $ays_slider_sale_date = get_option('ays_slider_sale_date_w');
    //     $ays_slider_sale_two_months = get_option('ays_slider_sale_dismiss_for_two_month_w');

    //     $val = 60*60*24*5;
    //     if($ays_slider_sale_two_months == 1){
    //         $val = 60*60*24*61;
    //     }

    //     $current_date = current_time( 'mysql' );
    //     $date_diff = strtotime($current_date) - intval(strtotime($ays_slider_sale_date)) ;
        
    //     $days_diff = $date_diff / $val;
    
    //     if(intval($days_diff) > 0 ){
    //         update_option('ays_slider_sale_notification_w', 0);
    //         update_option('ays_slider_sale_dismiss_for_two_month_w', 0);
    //     }
    
    //     $ays_slider_flag = intval(get_option('ays_slider_sale_notification_w'));
    //     $ays_slider_flag += intval(get_option('ays_slider_sale_dismiss_for_two_month_w'));
    //     if( $ays_slider_flag == 0 ){
    //         if (isset($_GET['page']) && strpos($_GET['page'], AYS_SLIDER_NAME) !== false) {
    //             // $this->ays_slider_sale_message_black_friday($ays_slider_flag);
    //             $this->ays_slider_winter_bundle_message($ays_slider_flag);
    //         }
    //     }
    // }

    public function ays_slider_sale_message_black_friday($flag){
        if($flag == 0){
            $content = array();

            $content[] = '<div id="ays-slider-dicount-month-main" class="notice notice-success is-dismissible ays_slider_dicount_info">';
                $content[] = '<div id="ays-slider-dicount-month" class="ays_slider_dicount_month">';

                    $content[] = '<div class="ays-slider-dicount-wrap-box">';

                    $content[] = '<strong style="font-weight: bold;">';
                        $content[] = __( "Limited Time <span class='ays-slider-dicount-wrap-color'>50%</span> SALE on <br><span><a href='https://ays-pro.com/business-bundle' target='_blank' class='ays-slider-dicount-wrap-color ays-slider-dicount-wrap-text-decoration' style='display:block;'>Business Bundle</a></span> (All 13 plugins)" , AYS_SLIDER_NAME );
                    $content[] = '</strong>';

                        $content[] = '<br>';


                        $content[] = '<strong>';
                                $content[] = __( "Hurry up! Ends on November 26. <a href='https://ays-pro.com/business-bundle' target='_blank'>Check it out!</a>", AYS_SLIDER_NAME );
                        $content[] = '</strong>';
                        

                            
                    $content[] = '</div>';

                    $content[] = '<div class="ays-slider-dicount-wrap-box">';

                        $content[] = '<div id="ays-slider-maker-countdown-main-container">';
                            $content[] = '<div class="ays-slider-maker-countdown-container">';

                                $content[] = '<div id="ays-slider-countdown">';
                                    $content[] = '<ul>';
                                        $content[] = '<li><span id="ays-slider-countdown-days"></span>days</li>';
                                        $content[] = '<li><span id="ays-slider-countdown-hours"></span>Hours</li>';
                                        $content[] = '<li><span id="ays-slider-countdown-minutes"></span>Minutes</li>';
                                        $content[] = '<li><span id="ays-slider-countdown-seconds"></span>Seconds</li>';
                                    $content[] = '</ul>';
                                $content[] = '</div>';

                                $content[] = '<div id="ays-slider-countdown-content" class="emoji">';
                                    $content[] = '<span>🚀</span>';
                                    $content[] = '<span>⌛</span>';
                                    $content[] = '<span>🔥</span>';
                                    $content[] = '<span>💣</span>';
                                $content[] = '</div>';

                            $content[] = '</div>';

                            $content[] = '<form action="" method="POST">';
                                $content[] = '<div id="ays-slider-dismiss-buttons-content">';
                                    $content[] = '<button class="btn btn-link ays-button" name="ays_slider_maker_sale_btn" style="height: 32px; padding-left: 0">Dismiss ad</button>';
                                    $content[] = '<button class="btn btn-link ays-button" name="ays_slider_maker_sale_btn_for_two_months" style="height: 32px; padding-left: 0">Dismiss ad for 2 months</button>';
                                $content[] = '</div>';
                            $content[] = '</form>';
                        $content[] = '</div>';
                            
                    $content[] = '</div>';

                    $content[] = '<div class="ays-slider-dicount-wrap-box ays-buy-now-button-box">';
                        $content[] = '<a href="https://ays-pro.com/business-bundle" class="button button-primary ays-buy-now-button" id="ays-button-top-buy-now" target="_blank" style="" >' . __( 'Buy Now !', AYS_SLIDER_NAME ) . '</a>';
                    $content[] = '</div>';

                    $content[] = '<div class="ays-slider-dicount-wrap-box ays-slider-dicount-wrap-opacity-box">';
                        $content[] = '<a href="https://ays-pro.com/business-bundle" class="ays-buy-now-opacity-button" target="_blank">' . __( 'link', AYS_SLIDER_NAME ) . '</a>';
                    $content[] = '</div>';

                $content[] = '</div>';
            $content[] = '</div>';

            $content = implode( '', $content );
            echo $content;
            ?>
            <?php
        }
    }

    // public function ays_slider_winter_bundle_message($flag){
    //     if($flag == 0 ){
    //         $content = array();
    //         $content[] = '<div id="ays-slider-dicount-month-main" class="notice notice-success is-dismissible ays_slider_dicount_info">';
    //             $content[] = '<div id="ays-slider-dicount-month" class="ays_slider_dicount_month">';
    //                 $content[] = '<a href="https://ays-pro.com/winter-bundle" target="_blank" class="ays-slider-sale-banner-link"><img src="' . AYS_SLD_ADMIN_URL . 'images/winter_bundle_logo.png"></a>';

    //                 $content[] = '<div class="ays-slider-dicount-wrap-box">';

    //                     $content[] = '<strong>';
    //                         $content[] = __( "Limited Time <span class='ays-slider-dicount-wrap-color'>50%</span> SALE on <br><span><a href='https://ays-pro.com/winter-bundle' target='_blank' class='ays-slider-dicount-wrap-color ays-slider-dicount-wrap-text-decoration' style='display:block;'>Winter Bundle</a></span> (Copy + Popup + Survey)!", AYS_SLIDER_NAME );
    //                     $content[] = '</strong>';

    //                     $content[] = '<br>';

    //                     $content[] = '<strong>';
    //                             $content[] = __( "Hurry up! Ends on January 1. <a href='https://ays-pro.com/winter-bundle' target='_blank'>Check it out!</a>", AYS_SLIDER_NAME );
    //                     $content[] = '</strong>';
                            
    //                 $content[] = '</div>';

    //                 $content[] = '<div class="ays-slider-dicount-wrap-box">';

    //                     $content[] = '<div id="ays-slider-countdown-main-container">';
    //                         $content[] = '<div class="ays-slider-countdown-container">';

    //                             $content[] = '<div id="ays-slider-countdown">';
    //                                 $content[] = '<ul>';
    //                                     $content[] = '<li><span id="ays-slider-countdown-days"></span>days</li>';
    //                                     $content[] = '<li><span id="ays-slider-countdown-hours"></span>Hours</li>';
    //                                     $content[] = '<li><span id="ays-slider-countdown-minutes"></span>Minutes</li>';
    //                                     $content[] = '<li><span id="ays-slider-countdown-seconds"></span>Seconds</li>';
    //                                 $content[] = '</ul>';
    //                             $content[] = '</div>';

    //                             $content[] = '<div id="ays-slider-countdown-content" class="emoji">';
    //                                 $content[] = '<span>🚀</span>';
    //                                 $content[] = '<span>⌛</span>';
    //                                 $content[] = '<span>🔥</span>';
    //                                 $content[] = '<span>💣</span>';
    //                             $content[] = '</div>';

    //                         $content[] = '</div>';

    //                         $content[] = '<form action="" method="POST">';
	// 							$content[] ='<div id="ays-slider-dismiss-buttons-content" style="margin: auto;display:flex;">';
	// 								$content[] = '<button class="btn btn-link ays-button" name="ays_slider_sale_btn_winter" style="height: 32px; margin-left: 0;padding-left: 0;cursor:pointer;">Dismiss ad</button>';
	// 								$content[] = '<button class="btn btn-link ays-button" name="ays_slider_sale_btn_winter_for_two_months" style="height: 32px; padding-left: 0;margin-left:5px; cursor:pointer;">Dismiss ad for 2 months</button>';
	// 							$content[] ='</div>';
    //                         $content[] = '</form>';

    //                     $content[] = '</div>';
                            
    //                 $content[] = '</div>';

    //                 $content[] = '<a href="https://ays-pro.com/winter-bundle" class="button button-primary ays-button" id="ays-button-top-buy-now" target="_blank">' . __( 'Buy Now !', AYS_SLIDER_NAME ) . '</a>';
    //             $content[] = '</div>';
    //         $content[] = '</div>';

    //         $content = implode( '', $content );
    //         echo $content;
    //     }
    // }
}