<?php

/**
 * The plugin bootstrap file
 *
 * This file is read by WordPress to generate the plugin information in the plugin
 * admin area. This file also includes all of the dependencies used by the plugin,
 * registers the activation and deactivation functions, and defines a function
 * that starts the plugin.
 *
 * @link              https://ays-pro.com/
 * @since             1.0.0
 * @package           Ays_Slider
 *
 * @wordpress-plugin
 * Plugin Name:       AYS Slider
 * Plugin URI:        https://ays-pro.com/index.php/wordpress/image-slider/
 * Description:       Create Beautifull And Responsive Sliders With Effects
 * Version:           2.6.0
 * Author:            Image Slider Team
 * Author URI:        https://ays-pro.com/
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       ays-slider
 * Domain Path:       /languages
 */

// If this file is called directly, abort.
if (!defined('WPINC')) {
    die;
}

if (!defined('AYS_SLD_BASE_URL')) {
    define('AYS_SLD_BASE_URL', plugin_dir_url(__FILE__));
}

if (!defined('AYS_SLD_ADMIN_URL')) {
    define('AYS_SLD_ADMIN_URL', plugin_dir_url(__FILE__) . 'admin/');
}

if (!defined('AYS_SLD_PUBLIC_URL')) {
    define('AYS_SLD_PUBLIC_URL', plugin_dir_url(__FILE__) . 'public/');
}
/**
 * Currently plugin version.
 * Start at version 1.0.0 and use SemVer - https://semver.org
 * Rename this for your plugin and update it as you release new versions.
 */
define('AYS_SLIDER_VERSION', '2.6.0');
define('AYS_SLIDER_NAME', 'ays-slider');

/**
 * The code that runs during plugin activation.
 * This action is documented in includes/class-ays-slider-activator.php
 */
function activate_ays_slider() {
    require_once plugin_dir_path(__FILE__) . 'includes/class-ays-slider-activator.php';
    Ays_Slider_Activator::ays_slider_db_check();
}

/**
 * The code that runs during plugin deactivation.
 * This action is documented in includes/class-ays-slider-deactivator.php
 */
function deactivate_ays_slider() {
    require_once plugin_dir_path(__FILE__) . 'includes/class-ays-slider-deactivator.php';
    Ays_Slider_Deactivator::deactivate();
}

register_activation_hook(__FILE__, 'activate_ays_slider');
register_deactivation_hook(__FILE__, 'deactivate_ays_slider');
add_action('plugins_loaded', 'activate_ays_slider');
/**
 * The core plugin class that is used to define internationalization,
 * admin-specific hooks, and public-facing site hooks.
 */
require plugin_dir_path(__FILE__) . 'includes/class-ays-slider.php';

/**
 * The Gutenberg block registration.
 */
// require plugin_dir_path(__FILE__) . 'gutenberg/ays-slider-block.php';

/**
 * Begins execution of the plugin.
 *
 * Since everything within the plugin is registered via hooks,
 * then kicking off the plugin from this point in the file does
 * not affect the page life cycle.
 *
 * @since    1.0.0
 */
function run_ays_slider() {
    add_action('admin_notices', 'general_asp_admin_notice');
    $plugin = new Ays_Slider();
    $plugin->run();

}
function general_asp_admin_notice() {
    if (isset($_GET['page']) && strpos($_GET['page'], AYS_SLIDER_NAME) !== false) {
        ?>
        <div class="ays-notice-banner">
            <div class="navigation-bar">
                <div id="navigation-container">
                    <ul id="menu">
                        <li class="modile-ddmenu-xss"><a class="ays-btn" href="https://ays-pro.com/index.php/wordpress/image-slider/" target="_blank"><i class="fas fa-gem ays-fa-margin-right"></i>PRO</a></li>
                        <li class="modile-ddmenu-lg"><a class="ays-btn" href="https://plugins.ays-demo.com/slider-free-demo/" target="_blank">Demo</a></li>
                        <li class="modile-ddmenu-lg"><a class="ays-btn" href="https://wordpress.org/support/plugin/ays-slider" target="_blank">Support
                                Chat</a></li>
                        <li class="modile-ddmenu-lg"><a class="ays-btn" href="https://wordpress.org/support/plugin/ays-slider" target="_blank">Contact us</a></li>
                        <li class="modile-ddmenu-md">
                            <a class="toggle_ddmenu" href="javascript:void(0);"><i class="fas fa-ellipsis-h"></i></a>
                            <ul class="ddmenu" data-expanded="false">
                                <li><a class="ays-btn" href="https://plugins.ays-demo.com/slider-free-demo/" target="_blank">Demo</a></li>
                                <li><a class="ays-btn" href="https://wordpress.org/support/plugin/ays-slider" target="_blank">Support
                                Chat</a></li>
                                <li><a class="ays-btn" href="https://wordpress.org/support/plugin/ays-slider" target="_blank">Contact us</a></li>
                            </ul>
                        </li>
                        <li class="modile-ddmenu-sm">
                            <a class="toggle_ddmenu" href="javascript:void(0);"><i class="fas fa-ellipsis-h"></i></a>
                            <ul class="ddmenu" data-expanded="false">
                                <li><a class="ays-btn" href="https://plugins.ays-demo.com/slider-free-demo/" target="_blank">Demo</a></li>
                                <li><a class="ays-btn" href="https://wordpress.org/support/plugin/ays-slider" target="_blank">Support
                                Chat</a></li>
                                <li><a class="ays-btn" href="https://wordpress.org/support/plugin/ays-slider" target="_blank">Contact us</a></li>
                            </ul>
                        </li>
                    </ul>
                </div>
            </div>
        </div>
        <?php
    }
}

run_ays_slider();