<?php
ob_start();
class Ays_Slider_List_Table extends WP_List_Table {
    private $plugin_name;
    /** Class constructor */
    public function __construct($plugin_name) {
        $this->plugin_name = $plugin_name;
        parent::__construct(array(
            "singular" => __("Slider", $this->plugin_name), //singular name of the listed records
            "plural" => __("Sliders", $this->plugin_name), //plural name of the listed records
            "ajax" => false, //does this table support ajax?
        ));
        add_action("admin_notices", array($this, "ays_slider_notices"));

    }

    /**
     * Retrieve customers data from the database
     *
     * @param int $per_page
     * @param int $page_number
     *
     * @return mixed
     */
    public static function get_sliders($per_page = 20, $page_number = 1 , $search = '') {

        global $wpdb;

        $sql = "SELECT * FROM {$wpdb->prefix}ays_slider";

        $where = array();

        if( $search != '' ){
            $where[] = $search;
        }

        if( ! empty($where) ){
            $sql .= " WHERE " . implode( " AND ", $where );
        }



        if ( ! empty( $_REQUEST['orderby'] ) ) {

            $order_by  = ( isset( $_REQUEST['orderby'] ) && sanitize_text_field( $_REQUEST['orderby'] ) != '' ) ? sanitize_text_field( $_REQUEST['orderby'] ) : 'ordering';
            $order_by .= ( ! empty( $_REQUEST['order'] ) && strtolower( $_REQUEST['order'] ) == 'asc' ) ? ' ASC' : ' DESC';

            $sql_orderby = sanitize_sql_orderby($order_by);

            if ( $sql_orderby ) {
                $sql .= ' ORDER BY ' . $sql_orderby;
            } else {
                $sql .= ' ORDER BY id DESC';
            }
        }else{
            $sql .= ' ORDER BY id DESC';
        }

        $sql .= " LIMIT $per_page";
        $sql .= " OFFSET " . ($page_number - 1) * $per_page;

        $result = $wpdb->get_results($sql, "ARRAY_A");

        return $result;
    }

    public function get_slider_by_id($id) {
        global $wpdb;

        $sql = "SELECT * FROM {$wpdb->prefix}ays_slider WHERE id=" . absint(sanitize_text_field($id));

        $result = $wpdb->get_row($sql, "ARRAY_A");

        return $result;
    }

    public function add_or_edit_slider($data) {
        global $wpdb;
        $slider_table = $wpdb->prefix . "ays_slider";

        if (isset($data["ays_slider_action"]) && wp_verify_nonce($data["ays_slider_action"], "ays_slider_action")) {            
            $id = (isset($data["id"]) && 0 != $data["id"]) ? absint($data["id"]) : null;
            $title = wp_unslash(sanitize_text_field($data["slider_title"]));
            $description = wp_unslash(sanitize_text_field($data["slider_description"]));
            $width = wp_unslash(sanitize_text_field($data['slider_width']));
            $height = absint($data["slider_height"]);

            foreach ($data["ays-image-path"] as $index => $path) {
                if (wp_http_validate_url($path)===false || empty($path)) {
                    unset($data["ays-image-path"][$index]);
                    unset($data["ays-image-title"][$index]);
                    unset($data["ays-image-alt"][$index]);
                    unset($data["ays-image-description"][$index]);
                    unset($data["ays-image-url"][$index]);
                    unset($data["ays-image-date"][$index]);
                }
            }

            $image_paths           = isset($data["ays-image-path"]) ? sanitize_text_field(implode("***", $data["ays-image-path"])) : "";
            $image_titles          = isset($data["ays-image-title"]) ? sanitize_text_field(implode("***", $data["ays-image-title"])) : "";
            $image_alts            = isset($data["ays-image-alt"]) ? sanitize_text_field(implode("***", $data["ays-image-alt"])) : "";
            $image_descriptions    = isset($data["ays-image-description"]) ? sanitize_text_field(implode("***", $data["ays-image-description"])) : "";
            $image_external_urls   = isset($data["ays-image-url"]) ? sanitize_text_field(implode("***", $data["ays-image-url"])) : "";
            $images_dates          = isset($data['ays-image-date']) ? sanitize_text_field(implode("***", $data['ays-image-date'])) : "";
            $border_radius         = isset($data['ays-sld-border-radius']) && $data['ays-sld-border-radius'] != "" ? absint($data['ays-sld-border-radius']) : "";
            $images_distance       = isset($data['ays-sld-images-distance']) ? absint($data['ays-sld-images-distance']) : "";
            $custom_class          = isset($data['slider_custom_class']) ? wp_unslash(sanitize_text_field($data['slider_custom_class'])) : "";
            $custom_css            = isset($data['slider_custom_css']) ? stripslashes ( esc_attr($data['slider_custom_css'])) : "";
            $images_orderby        = wp_unslash(sanitize_text_field($data['ays_images_ordering']));
            $image_object_fit      = isset($data['ays_images_object_fit']) ? wp_unslash(sanitize_text_field($data['ays_images_object_fit'])) : "";
            $slider_bgcolor        = isset($data['slider_bgcolor']) ? wp_unslash(sanitize_text_field($data['slider_bgcolor'])) : "";
            $slider_title_color    = isset($data['ays_slider_title_color']) ? wp_unslash(sanitize_text_field($data['ays_slider_title_color'])) : '#FFFFFF';
            $show_title            = isset($data['ays_sld_show_title']) && sanitize_text_field($data['ays_sld_show_title']) == 'on' ? 1 : 0;
            $pause_hover           = isset($data['ays_sld_pause_hover']) && sanitize_text_field($data['ays_sld_pause_hover']) == 'on' ? 1 : 0;
            $nav_arrows            = isset($data['ays_sld_nav_arrows']) && $data['ays_sld_nav_arrows'] == 'on' ? 1 : 0;
            $nav_type              = isset($data['ays_sld_nav_type']) ? sanitize_text_field($data['ays_sld_nav_type']) : "";
            $active_tab            = isset($data['ays-sld-active-tab']) ? sanitize_text_field($data['ays-sld-active-tab']) : "";
            $nav_type_thumb_width  = isset($data['ays-sld-thumb-w']) && absint($data['ays-sld-thumb-w']) != 0 ? absint($data['ays-sld-thumb-w']) : 50;
            $nav_type_thumb_height = isset($data['ays-sld-thumb-h']) && absint($data['ays-sld-thumb-h']) != 0 ? absint($data['ays-sld-thumb-h']) : 50;
            $nav_type_thumb_count  = isset($data['ays-sld-thumb-c']) && absint($data['ays-sld-thumb-c']) != 0 ? absint($data['ays-sld-thumb-c']) : 3;
            $ays_admin_pagination  = wp_unslash(sanitize_text_field($data['ays_admin_pagination']));
            $ays_images_loading    = wp_unslash(sanitize_text_field($data['ays_images_loading']));
            $ays_animation_in      = isset($data['ays_sld_animation_in']) ? sanitize_text_field($data['ays_sld_animation_in']) : '';
            $ays_animation_out     = isset($data['ays_sld_animation_out']) ? sanitize_text_field($data['ays_sld_animation_out']) : '';
            $ays_animation_speed   = isset($data['ays_sld_animation_speed']) && absint($data['ays_sld_animation_speed']) != 0 ? absint($data['ays_sld_animation_speed']) : 400;
            $ays_timeout           = isset($data['ays-sld-timeout']) && absint($data['ays-sld-timeout']) > 499 ? absint($data['ays-sld-timeout']) : 3000;
            $css_filter            = isset($data['ays_slider_image_filter']) ? sanitize_text_field($data['ays_slider_image_filter']) : "";
            $css_filter_value      = isset($data['ays-filter-' . $css_filter]) ? sanitize_text_field($data['ays-filter-' . $css_filter]) : "";

            $options = array(
                'admin_pagination'   => $ays_admin_pagination,
                'nav_arrows'         => $nav_arrows,
                'nav_type'           => $nav_type,
                'thumb_w'            => $nav_type_thumb_width,
                'thumb_h'            => $nav_type_thumb_height,
                'thumb_c'            => $nav_type_thumb_count,
                'show_title'         => $show_title,
                'pause_hover'        => $pause_hover,
                'images_orderby'     => $images_orderby,
                'margin'             => $images_distance,
                'images_loading'     => $ays_images_loading,
                'animation_in'       => $ays_animation_in,
                'animation_out'      => $ays_animation_out,
                'animation_speed'    => $ays_animation_speed,
                'border_radius'      => $border_radius,
                'timeout'            => $ays_timeout,
                'filter'             => $css_filter,
                'filter_value'       => $css_filter_value,
                'active_tab'         => $active_tab,
                'image_object_fit'   => $image_object_fit,
                'slider_bgcolor'     => $slider_bgcolor,
                'slider_title_color' => $slider_title_color,
                "custom_class"       => $custom_class,
            );
            $submit_type = (isset($data['submit_type'])) ? $data['submit_type'] : '';
            if (null == $id) {
                $slider_result = $wpdb->insert(
                    $slider_table,
                    array(
                        "title"         => $title,
                        "description"   => $description,
                        "images"        => $image_paths,
                        "images_titles" => $image_titles,
                        "images_descs"  => $image_descriptions,
                        "images_alts"   => $image_alts,
                        "images_urls"   => $image_external_urls,
                        "images_dates"  => $images_dates,
                        "width"         => $width,
                        "height"        => $height,
                        "custom_css"    => $custom_css,
                        "options"       => json_encode($options, true),
                    ),
                    array("%s", "%s", "%s", "%s", "%s", "%s", "%s", "%s", "%d", "%d", "%s", "%s")
                );
                $last_id = $wpdb->insert_id;
                $message = "created";
            } else {
                $slider_result = $wpdb->update(
                    $slider_table,
                    array(
                        "title"         => $title,
                        "description"   => $description,
                        "images"        => $image_paths,
                        "images_titles" => $image_titles,
                        "images_descs"  => $image_descriptions,
                        "images_alts"   => $image_alts,
                        "images_urls"   => $image_external_urls,
                        "images_dates"  => $images_dates,
                        "width"         => $width,
                        "height"        => $height,
                        "custom_css"    => $custom_css,
                        "options"       => json_encode($options, true),
                    ),
                    array("id" => $id),
                    array("%s", "%s", "%s", "%s", "%s", "%s", "%s", "%s", "%d", "%d", "%s", "%s"),
                    array("%d")
                );
                $message = "updated";
            }
            if ($slider_result >= 0) {
                if ('' == $submit_type) {
                    $url = esc_url_raw(remove_query_arg(["action", "slider"])) . "&status=" . $message . "&type=success";
                    wp_redirect($url);
                    exit();
                } else {
                    $url = esc_url_raw(add_query_arg(array("status" => $message))) . "&type=success" . ($message == 'created' ? "&slider=$last_id" : "");
                    wp_redirect($url);
                    exit();
                }
            }
        }
    }

    /**
     * Delete a customer record.
     *
     * @param int $id customer ID
     */
    public static function delete_sliders($id) {
        global $wpdb;
        $wpdb->delete(
            "{$wpdb->prefix}ays_slider",
            array("id" => $id),
            array("%d")
        );
    }

    /**
     * Returns the count of records in the database.
     *
     * @return null|string
     */
    public static function record_count() {
        global $wpdb;

        $filter = array();

        $sql = "SELECT COUNT(*) FROM {$wpdb->prefix}ays_slider";

        $search = ( isset( $_REQUEST['s'] ) ) ? esc_sql( sanitize_text_field( $_REQUEST['s'] ) ) : false;
        if( $search ){
            $filter[] = sprintf(" title LIKE '%%%s%%' ", esc_sql( $wpdb->esc_like( $search ) ) );
        }
        
        if(count($filter) !== 0){
            $sql .= " WHERE ".implode(" AND ", $filter);
        }


        return $wpdb->get_var($sql);
    }

    /** Text displayed when no customer data is available */
    public function no_items() {
        _e("There are no sliders yet.", $this->plugin_name);
    }

    /**
     * Render a column when no column specific method exist.
     *
     * @param array $item
     * @param string $column_name
     *
     * @return mixed
     */
    public function column_default($item, $column_name) {
        switch ($column_name) {
        case "title":
        case "description":
            return wp_unslash($item[$column_name]);
            break;
        case "shortcode":
        case "id":
            return $item[$column_name];
            break;
        default:
            return print_r($item, true); //Show the whole array for troubleshooting purposes
        }
    }

    /**
     * Render the bulk edit checkbox
     *
     * @param array $item
     *
     * @return string
     */
    function column_cb($item) {
        return sprintf(
            "<input type='checkbox' name='bulk-delete[]' value='%s' />", $item["id"]
        );
    }

    /**
     * Method for name column
     *
     * @param array $item an array of DB data
     *
     * @return string
     */
    function column_title($item) {
        $delete_nonce = wp_create_nonce($this->plugin_name . "-delete-slider");

        $title = sprintf("<a href='?page=%s&action=%s&slider=%d'>%s</a>", esc_attr($_REQUEST["page"]), "edit", absint($item["id"]), esc_attr($item['title']));

        $actions = [
            "edit" => sprintf("<a href='?page=%s&action=%s&slider=%d'>" . __('Edit', $this->plugin_name) . "</a>", esc_attr($_REQUEST["page"]), "edit", absint($item["id"])),
            "delete" => sprintf("<a href='?page=%s&action=%s&slider=%s&_wpnonce=%s'>" . __('Delete', $this->plugin_name) . "</a>", esc_attr($_REQUEST["page"]), "delete", absint($item["id"]), $delete_nonce),
        ];

        return $title . $this->row_actions($actions);
    }

    function column_shortcode($item) {
        return sprintf("<input type='text' onClick='this.setSelectionRange(0, this.value.length)' readonly value='[ays_slider id=%s]'/>", $item["id"]);
    }

    /**
     *  Associative array of columns
     *
     * @return array
     */
    function get_columns() {
        $columns = array(
            "cb"            => "<input type='checkbox'>",
            "title"         => __("Title", $this->plugin_name),
            "description"   => __("Description", $this->plugin_name),
            "shortcode"     => __("Shortcode", $this->plugin_name),
            "id"            => __("ID", $this->plugin_name),
        );

        return $columns;
    }

    /**
     * Columns to make sortable.
     *
     * @return array
     */
    public function get_sortable_columns() {
        $sortable_columns = array(
            "title" => array("title", true),
            "id"    => array("id", true),
        );

        return $sortable_columns;
    }

    /**
     * Returns an associative array containing the bulk action
     *
     * @return array
     */
    public function get_bulk_actions() {
        $actions = array(
            "bulk-delete" => __("Delete", $this->plugin_name),
        );

        return $actions;
    }

    /**
     * Handles data query and filter, sorting, and pagination.
     */
    public function prepare_items() {
        global $wpdb;

        $this->_column_headers = $this->get_column_info();

        /** Process bulk action */
        $this->process_bulk_action();

        $per_page       = $this->get_items_per_page("sliders_per_page", 20);
        $current_page   = $this->get_pagenum();
        $total_items    = self::record_count();

        $this->set_pagination_args(array(
            "total_items"   => $total_items, //WE have to calculate the total number of items
            "per_page"      => $per_page, //WE have to determine how many items to show on a page
        ));


        $search = ( isset( $_REQUEST['s'] ) ) ? esc_sql( sanitize_text_field( $_REQUEST['s'] ) ) : false;

        $do_search = ( $search ) ? sprintf(" title LIKE '%%%s%%' ", esc_sql( $wpdb->esc_like( $search ) ) ) : '';


        $this->items = $this->get_sliders( $per_page, $current_page , $do_search );

    }

    public function process_bulk_action() {
        //Detect when a bulk action is being triggered...
        $message = "deleted";
        if ("delete" === $this->current_action()) {

            // In our file that handles the request, verify the nonce.
            $nonce = esc_attr($_REQUEST["_wpnonce"]);

            if (!wp_verify_nonce($nonce, $this->plugin_name . "-delete-slider")) {
                die("Go get a life script kiddies");
            } else {
                self::delete_sliders(absint($_GET["slider"]));

                // esc_url_raw() is used to prevent converting ampersand in url to "#038;"
                // add_query_arg() return the current url

                $url = esc_url_raw(remove_query_arg(array("action", "slider", "_wpnonce"))) . "&status=" . $message . "&type=success";
                wp_redirect($url);
                exit();
            }

        }

        // If the delete bulk action is triggered
        if ((isset($_POST["action"]) && "bulk-delete" == $_POST["action"])
            || (isset($_POST["action2"]) && "bulk-delete" == $_POST["action2"])
        ) {

            $delete_ids = ( isset( $_POST['bulk-delete'] ) && ! empty( $_POST['bulk-delete'] ) ) ? esc_sql( $_POST['bulk-delete'] ) : array();

            // loop over the array of record IDs and delete them
            foreach ($delete_ids as $id) {
                self::delete_sliders($id);

            }

            // esc_url_raw() is used to prevent converting ampersand in url to "#038;"
            // add_query_arg() return the current url

            $url = esc_url_raw(remove_query_arg(array("action", "slider", "_wpnonce"))) . "&status=" . $message . "&type=success";
            wp_redirect($url);
            exit();
        }
    }

    public function ays_slider_notices() {
        $status = (isset($_REQUEST["status"])) ? sanitize_text_field($_REQUEST["status"]) : "";
        $type = (isset($_REQUEST["type"])) ? sanitize_text_field($_REQUEST["type"]) : "";

        if (empty($status)) {
            return;
        }

        if ("created" == $status) {
            $updated_message = esc_html(__("Slider created.", $this->plugin_name));
        } elseif ("updated" == $status) {
            $updated_message = esc_html(__("Slider saved.", $this->plugin_name));
        } elseif ("deleted" == $status) {
            $updated_message = esc_html(__("Slider deleted.", $this->plugin_name));
        } elseif ("error" == $status) {
            $updated_message = __("You're not allowed to add slider for more sliders please checkout to ", $this->plugin_name) . "<a href='http://ays-pro.com/index.php/wordpress/ays-slider' target='_blank'>PRO " . __("version", $this->plugin_name) . "</a>.";
        }

        if (empty($updated_message)) {
            return;
        }

        ?>
<div class="notice notice-<?php echo esc_attr($type); ?> is-dismissible">
    <p>
        <?php echo $updated_message; ?>
    </p>
</div>
<?php
}
}